@@ -13,18 +13,20 @@ class AIOHTTPOpenAPIWebResponse:
         self.response = response
 
     @property
-    def data(self) -> str:
+    def data(self) -> bytes:
+        if self.response.body is None:
+            return b""
         if isinstance(self.response.body, bytes):
-            return self.response.body.decode("utf-8")
+            return self.response.body
         assert isinstance(self.response.body, str)
-        return self.response.body
+        return self.response.body.encode("utf-8")
 
     @property
     def status_code(self) -> int:
         return self.response.status
 
     @property
-    def mimetype(self) -> str:
+    def content_type(self) -> str:
         return self.response.content_type or ""
 
     @property
